<?php

namespace App\Http\Controllers\API\Rider;

use App\Http\Controllers\Controller;
use App\Http\Requests\WithdrawRequest;
use App\Http\Resources\WithdrawResource;
use App\Models\GeneraleSetting;
use App\Models\Notification;
use App\Models\Withdraw;
use App\Repositories\WithdrawRepository;
use Carbon\Carbon;

class WithdrawController extends Controller
{
    /**
     * show withdraw
     */
    public function index()
    {
        $request = request();
        $page = $request->page ?? 1;
        $perPage = $request->per_page ?? 15;
        $skip = ($page * $perPage) - $perPage;

        $withdraws = $request->user()->withdraws()->latest('id')->skip($skip)->take($perPage)->get();

        return $this->json('withdraw list', [
            'withdraws' => WithdrawResource::collection($withdraws),
        ]);
    }

    /**
     * store a new withdraw request
     */
    public function store(WithdrawRequest $request)
    {

        $pendingWitthdraws = $request->user()->withdraws()->where('status', 0)->sum('amount');
        $walletBalance = auth()->user()->wallet?->balance;

        $latestPendingWithdraw = $request->user()->withdraws()->where('status', 0)->latest('id')->first();
        $generaleSetting = GeneraleSetting::first();

        $isWithdrawable = true;
        $minDayRequest = $generaleSetting?->withdraw_request;

        if ($latestPendingWithdraw && $minDayRequest > 0) {
            $isWithdrawable = $latestPendingWithdraw->created_at->diffInDays(Carbon::now()) >= $minDayRequest;
        }

        if (! $isWithdrawable) {
            return $this->json(__('Sorry! Withdraw request is not available!'), [], 422);
        }

        if (($walletBalance - $pendingWitthdraws) < $request->amount) {
            return $this->json(__('Sorry! Insufficient balance!'),[], 422);
        }
        
        WithdrawRepository::storeByRequest($request);

        return $this->json(__('Withdraw request created successfully!'));
    }

    /**
     * destroy withdraw request
     */
    public function delete(Withdraw $withdraw)
    {
        Notification::where('withdraw_id', $withdraw->id)->delete();
        $withdraw->delete();

        return $this->json(__('Withdraw request deleted successfully!'));
    }
}