<?php

namespace App\Http\Controllers\Admin;

use App\Enums\OrderStatus;
use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Customer;
use App\Models\Order;
use App\Models\Product;
use App\Repositories\WithdrawRepository;

class DashboardController extends Controller
{
    /**
     * Show the application dashboard.
     */
    public function index()
    {
        $generleSetting = generaleSetting('setting');

        $totalCustomer = Customer::count();

        $totalOrder = Order::count();
        $totalProduct = Product::count();
        $totalCategories = Category::count();

        $orderStatuses = OrderStatus::cases();

        $topCustomers = Customer::withCount('orders')->orderBy('orders_count', 'desc')->limit(8)->get();

        $topSellingProducts = Product::withCount('orders')->orderBy('orders_count', 'desc')->limit(8)->get();

        $topReviewProducts = Product::withAvg('reviews as average_rating', 'rating')->orderBy('average_rating', 'desc')->limit(8)->get();

        $latestOrders = Order::latest('id')->limit(6)->get();

        $topFavorites = Product::whereHas('favorites')->withCount('favorites')->orderBy('favorites_count', 'desc')->limit(8)->get();

        $pendingWithdraw = WithdrawRepository::query()->where('status', 'pending')->sum('amount');
        $alreadyWithdraw = WithdrawRepository::query()->where('status', 'approved')->sum('amount');
        $deniedWithddraw = WithdrawRepository::query()->where('status', 'denied')->sum('amount');

        $totalWithdraw = $pendingWithdraw + $alreadyWithdraw;

        return view('admin.dashboard', compact('totalOrder', 'totalCustomer', 'totalProduct', 'orderStatuses', 'topCustomers', 'topSellingProducts', 'topReviewProducts', 'latestOrders', 'topFavorites', 'totalCategories', 'alreadyWithdraw', 'pendingWithdraw', 'deniedWithddraw', 'totalWithdraw'));
    }
}
